==> g2plot-vue-3.1.5.tgz: package/CHANGELOG.md <==
## [3.1.5](https://github.com/open-data-plan/g2plot-vue/compare/v3.1.4...v3.1.5) (2021-03-03)


### Bug Fixes

* compatible with vue 2 ([bf772c1](https://github.com/open-data-plan/g2plot-vue/commit/bf772c19000a90b80dfaeff0c6e13b981924fbdf))



## [3.1.4](https://github.com/open-data-plan/g2plot-vue/compare/v3.1.3...v3.1.4) (2021-03-03)


### Bug Fixes

* fix vue 2 jsx transform error ([f503530](https://github.com/open-data-plan/g2plot-vue/commit/f503530aba2dd907527c7969d4b0b45a7f1d9d68))



## [3.1.3](https://github.com/open-data-plan/g2plot-vue/compare/v3.1.2...v3.1.3) (2021-03-03)


### Bug Fixes

* fix render error in vue 2 ([63d9901](https://github.com/open-data-plan/g2plot-vue/commit/63d99016d27f414bbd1ccdb8c0928f5e7ebe74d9))



## [3.1.2](https://github.com/open-data-plan/g2plot-vue/compare/v3.1.1...v3.1.2) (2021-03-03)


### Bug Fixes

* fix missed postinstall scripts ([3090f9a](https://github.com/open-data-plan/g2plot-vue/commit/3090f9afee68cc327e639ca3f515b706b4966976))



## [3.1.1](https://github.com/open-data-plan/g2plot-vue/compare/v3.1.0...v3.1.1) (2021-03-03)


### Bug Fixes

* fix output version ([407ef56](https://github.com/open-data-plan/g2plot-vue/commit/407ef562d8433266b07694af559530beeefa8416))



# [3.1.0](https://github.com/open-data-plan/g2plot-vue/compare/v3.0.1...v3.1.0) (2021-03-03)


### Features

* add MultiViewChart ([c7adfc1](https://github.com/open-data-plan/g2plot-vue/commit/c7adfc16cd911daab89d4511ca4705a8c61409f3))



## [3.0.1](https://github.com/open-data-plan/g2plot-vue/compare/v3.0.0...v3.0.1) (2021-03-03)


### Bug Fixes

* add g2plot to peer ([30f8ab3](https://github.com/open-data-plan/g2plot-vue/commit/30f8ab37517698148fb6dd6793b7af69a7ce4191))



# [3.0.0](https://github.com/open-data-plan/g2plot-vue/compare/v2.4.2...v3.0.0) (2021-03-03)


### Features

* support vue 2 ([67a657b](https://github.com/open-data-plan/g2plot-vue/commit/67a657bc61f3f13b2f05c3014371518128cbc035))



## [2.4.2](https://github.com/open-data-plan/g2plot-vue/compare/v2.4.0...v2.4.2) (2021-02-22)


### Bug Fixes

* fix types definitions ([39badf2](https://github.com/open-data-plan/g2plot-vue/commit/39badf2ea51a833185a915af29baf152f30dd939)), closes [#141](https://github.com/open-data-plan/g2plot-vue/issues/141)
* mark props as writeable ([ae73878](https://github.com/open-data-plan/g2plot-vue/commit/ae738782b5b43c9ec75a35fd6e566367bf007481)), closes [#138](https://github.com/open-data-plan/g2plot-vue/issues/138)



## [2.4.1](https://github.com/open-data-plan/g2plot-vue/compare/v2.4.0...v2.4.1) (2021-02-19)


### Bug Fixes

* mark props as writeable ([ae73878](https://github.com/open-data-plan/g2plot-vue/commit/ae738782b5b43c9ec75a35fd6e566367bf007481)), closes [#138](https://github.com/open-data-plan/g2plot-vue/issues/138)



# [2.4.0](https://github.com/open-data-plan/g2plot-vue/compare/v2.3.1...v2.4.0) (2021-01-15)

### Features

- introduce new charts ([dba197a](https://github.com/open-data-plan/g2plot-vue/commit/dba197a48ec3b8f70699045081b1e91797447348))

## [2.3.1](https://github.com/open-data-plan/g2plot-vue/compare/v2.3.0...v2.3.1) (2020-11-24)

# [2.3.0](https://github.com/open-data-plan/g2plot-vue/compare/v2.2.0...v2.3.0) (2020-11-10)

### Features

- add new chart ([2262259](https://github.com/open-data-plan/g2plot-vue/commit/2262259be07e415ab0142c851b225c5403657d71))

# [2.2.0](https://github.com/open-data-plan/g2plot-vue/compare/v2.1.0...v2.2.0) (2020-10-23)

### Features

- add new chart ([43c0882](https://github.com/open-data-plan/g2plot-vue/commit/43c08825b4cfa4134eca425a5507b3dfed474c5f))

# [2.1.0](https://github.com/open-data-plan/g2plot-vue/compare/v2.0.0...v2.1.0) (2020-10-16)

### Features

- add waterfall chart suport ([902ccd1](https://github.com/open-data-plan/g2plot-vue/commit/902ccd1c8d2344871335c888b20192eae6cda057))

# [2.0.0](https://github.com/open-data-plan/g2plot-vue/compare/v1.0.0...v2.0.0) (2020-10-13)

### Features

- compatible with g2plot v2 ([e71643c](https://github.com/open-data-plan/g2plot-vue/commit/e71643c8aaa9d037a8291d99a3e27bb02875e518))

# [1.0.0](https://github.com/open-data-plan/g2plot-vue/compare/c9116e3280cd5c18241cd101aa787063806fe19f...v1.0.0) (2020-09-01)

### Bug Fixes

- fix vue waring ([6cc5441](https://github.com/open-data-plan/g2plot-vue/commit/6cc54414038b93f2eb64098348333de365e65591))

### Features

- support g2plot chart ([c9116e3](https://github.com/open-data-plan/g2plot-vue/commit/c9116e3280cd5c18241cd101aa787063806fe19f))

==> g2plot-vue-3.1.6.tgz: package/CHANGELOG.md <==
## [3.1.6](https://github.com/open-data-plan/g2plot-vue/compare/v3.1.5...v3.1.6) (2021-03-19)

## [3.1.5](https://github.com/open-data-plan/g2plot-vue/compare/v3.1.4...v3.1.5) (2021-03-03)

### Bug Fixes

- compatible with vue 2 ([bf772c1](https://github.com/open-data-plan/g2plot-vue/commit/bf772c19000a90b80dfaeff0c6e13b981924fbdf))

## [3.1.4](https://github.com/open-data-plan/g2plot-vue/compare/v3.1.3...v3.1.4) (2021-03-03)

### Bug Fixes

- fix vue 2 jsx transform error ([f503530](https://github.com/open-data-plan/g2plot-vue/commit/f503530aba2dd907527c7969d4b0b45a7f1d9d68))

## [3.1.3](https://github.com/open-data-plan/g2plot-vue/compare/v3.1.2...v3.1.3) (2021-03-03)

### Bug Fixes

- fix render error in vue 2 ([63d9901](https://github.com/open-data-plan/g2plot-vue/commit/63d99016d27f414bbd1ccdb8c0928f5e7ebe74d9))

## [3.1.2](https://github.com/open-data-plan/g2plot-vue/compare/v3.1.1...v3.1.2) (2021-03-03)

### Bug Fixes

- fix missed postinstall scripts ([3090f9a](https://github.com/open-data-plan/g2plot-vue/commit/3090f9afee68cc327e639ca3f515b706b4966976))

## [3.1.1](https://github.com/open-data-plan/g2plot-vue/compare/v3.1.0...v3.1.1) (2021-03-03)

### Bug Fixes

- fix output version ([407ef56](https://github.com/open-data-plan/g2plot-vue/commit/407ef562d8433266b07694af559530beeefa8416))

# [3.1.0](https://github.com/open-data-plan/g2plot-vue/compare/v3.0.1...v3.1.0) (2021-03-03)

### Features

- add MultiViewChart ([c7adfc1](https://github.com/open-data-plan/g2plot-vue/commit/c7adfc16cd911daab89d4511ca4705a8c61409f3))

## [3.0.1](https://github.com/open-data-plan/g2plot-vue/compare/v3.0.0...v3.0.1) (2021-03-03)

### Bug Fixes

- add g2plot to peer ([30f8ab3](https://github.com/open-data-plan/g2plot-vue/commit/30f8ab37517698148fb6dd6793b7af69a7ce4191))

# [3.0.0](https://github.com/open-data-plan/g2plot-vue/compare/v2.4.2...v3.0.0) (2021-03-03)

### Features

- support vue 2 ([67a657b](https://github.com/open-data-plan/g2plot-vue/commit/67a657bc61f3f13b2f05c3014371518128cbc035))

## [2.4.2](https://github.com/open-data-plan/g2plot-vue/compare/v2.4.0...v2.4.2) (2021-02-22)

### Bug Fixes

- fix types definitions ([39badf2](https://github.com/open-data-plan/g2plot-vue/commit/39badf2ea51a833185a915af29baf152f30dd939)), closes [#141](https://github.com/open-data-plan/g2plot-vue/issues/141)
- mark props as writeable ([ae73878](https://github.com/open-data-plan/g2plot-vue/commit/ae738782b5b43c9ec75a35fd6e566367bf007481)), closes [#138](https://github.com/open-data-plan/g2plot-vue/issues/138)

## [2.4.1](https://github.com/open-data-plan/g2plot-vue/compare/v2.4.0...v2.4.1) (2021-02-19)

### Bug Fixes

- mark props as writeable ([ae73878](https://github.com/open-data-plan/g2plot-vue/commit/ae738782b5b43c9ec75a35fd6e566367bf007481)), closes [#138](https://github.com/open-data-plan/g2plot-vue/issues/138)

# [2.4.0](https://github.com/open-data-plan/g2plot-vue/compare/v2.3.1...v2.4.0) (2021-01-15)

### Features

- introduce new charts ([dba197a](https://github.com/open-data-plan/g2plot-vue/commit/dba197a48ec3b8f70699045081b1e91797447348))

## [2.3.1](https://github.com/open-data-plan/g2plot-vue/compare/v2.3.0...v2.3.1) (2020-11-24)

# [2.3.0](https://github.com/open-data-plan/g2plot-vue/compare/v2.2.0...v2.3.0) (2020-11-10)

### Features

- add new chart ([2262259](https://github.com/open-data-plan/g2plot-vue/commit/2262259be07e415ab0142c851b225c5403657d71))

# [2.2.0](https://github.com/open-data-plan/g2plot-vue/compare/v2.1.0...v2.2.0) (2020-10-23)

### Features

- add new chart ([43c0882](https://github.com/open-data-plan/g2plot-vue/commit/43c08825b4cfa4134eca425a5507b3dfed474c5f))

# [2.1.0](https://github.com/open-data-plan/g2plot-vue/compare/v2.0.0...v2.1.0) (2020-10-16)

### Features

- add waterfall chart suport ([902ccd1](https://github.com/open-data-plan/g2plot-vue/commit/902ccd1c8d2344871335c888b20192eae6cda057))

# [2.0.0](https://github.com/open-data-plan/g2plot-vue/compare/v1.0.0...v2.0.0) (2020-10-13)

### Features

- compatible with g2plot v2 ([e71643c](https://github.com/open-data-plan/g2plot-vue/commit/e71643c8aaa9d037a8291d99a3e27bb02875e518))

# [1.0.0](https://github.com/open-data-plan/g2plot-vue/compare/c9116e3280cd5c18241cd101aa787063806fe19f...v1.0.0) (2020-09-01)

### Bug Fixes

- fix vue waring ([6cc5441](https://github.com/open-data-plan/g2plot-vue/commit/6cc54414038b93f2eb64098348333de365e65591))

### Features

- support g2plot chart ([c9116e3](https://github.com/open-data-plan/g2plot-vue/commit/c9116e3280cd5c18241cd101aa787063806fe19f))
